use FlightStats_test;

DELIMITER //

CREATE PROCEDURE ontime_all_ins (num_pr INT)
BEGIN
  DECLARE done INT DEFAULT 0;

  DECLARE v_origin char(3);
  DECLARE v_destination char(3);
  DECLARE v_flight_num char(5);
  DECLARE v_flight_time smallint(5) unsigned;
  DECLARE v_tail_num char(8);
  DECLARE v_dep_time datetime;
  DECLARE v_arr_time datetime;
  DECLARE v_dep_delay smallint(6);
  DECLARE v_arr_delay smallint(6);
  DECLARE v_taxi_out smallint(6);
  DECLARE v_taxi_in smallint(6);
  DECLARE v_distance smallint(5) unsigned;
  DECLARE v_cancelled enum('Y','N');
  DECLARE v_diverted enum('Y','N');

  DECLARE cur1 CURSOR FOR
     SELECT 
        origin, destination, flight_num, flight_time,
        tail_num, dep_time, arr_time, dep_delay, arr_delay,
        taxi_out, taxi_in, distance, cancelled, diverted
     FROM ontime_1week WHERE id = num_pr;
  DECLARE CONTINUE HANDLER FOR SQLSTATE '01000' SET done = 1;
  DECLARE CONTINUE HANDLER FOR SQLSTATE '02000' SET done = 1;

  OPEN cur1;
  FETCH cur1 INTO 
        v_origin, v_destination, v_flight_num, v_flight_time,
        v_tail_num, v_dep_time, v_arr_time, v_dep_delay, v_arr_delay,
        v_taxi_out, v_taxi_in, v_distance, v_cancelled, v_diverted ;

  wl_loop: WHILE NOT done DO
     INSERT INTO ontime_all (
        id, carrier, origin, destination, flight_num, flight_time,
        tail_num, dep_time, arr_time, dep_delay, arr_delay,
        taxi_out, taxi_in, distance, cancelled, diverted
        ) 
        VALUES (
        num_pr, '__', v_origin, v_destination, v_flight_num, v_flight_time,
        v_tail_num, v_dep_time, v_arr_time, v_dep_delay, v_arr_delay,
        v_taxi_out, v_taxi_in, v_distance, v_cancelled, v_diverted
     );
     FETCH cur1 INTO 
        v_origin, v_destination, v_flight_num, v_flight_time,
        v_tail_num, v_dep_time, v_arr_time, v_dep_delay, v_arr_delay,
        v_taxi_out, v_taxi_in, v_distance, v_cancelled, v_diverted ;

  END WHILE wl_loop;
  CLOSE cur1;
END //

CREATE FUNCTION int_rand(num INT) RETURNS INT
BEGIN
   RETURN ROUND(num * RAND() + 0.5);
END //

DELIMITER ;

CREATE TABLE tb_logs (
   i1 INT NOT NULL AUTO_INCREMENT, PRIMARY KEY (i1),
   dt1 DATETIME NOT NULL,
   entry_dsc CHAR(100),
   f4 INT
);

CREATE TRIGGER ontime_ins AFTER INSERT ON ontime_all FOR EACH ROW
   INSERT INTO tb_logs (dt1, entry_dsc, f4)
   VALUES (NOW(), CONCAT('Insert row  ', NEW.flight_num,' ',
           NEW.origin, ' ', NEW.destination), NEW.id);

CREATE TRIGGER ontime_upd AFTER UPDATE ON ontime_all FOR EACH ROW
   INSERT INTO tb_logs (dt1, entry_dsc, f4)
   VALUES (NOW(), CONCAT('Update row ', NEW.flight_num,': ',
           OLD.distance, '->', NEW.distance), NEW.id);

CREATE TRIGGER ontime_del AFTER DELETE ON ontime_all FOR EACH ROW
   INSERT INTO tb_logs (dt1, entry_dsc, f4)
   VALUES (NOW(), CONCAT('Delete row ', OLD.flight_num), OLD.id);


