DROP DATABASE IF EXISTS FlightStats_test;

CREATE DATABASE FlightStats_test;


use FlightStats_test;

CREATE TABLE `aircraft` (
  `tail_num` char(6) NOT NULL default '',
  `aircraft_serial` char(20) NOT NULL default '',
  `aircraft_model_code` char(7) NOT NULL default '',
  `aircraft_engine_code` char(5) NOT NULL default '',
  `year_built` year(4) NOT NULL default '0000',
  `aircraft_type_id` tinyint(3) unsigned NOT NULL default '0',
  `aircraft_engine_type_id` tinyint(3) unsigned NOT NULL default '0',
  `registrant_type_id` tinyint(3) unsigned NOT NULL default '0',
  `name` char(50) NOT NULL default '',
  `address1` char(33) NOT NULL default '',
  `address2` char(33) NOT NULL default '',
  `city` char(18) NOT NULL default '',
  `state` char(2) NOT NULL default '',
  `zip` char(10) NOT NULL default '',
  `region` char(1) NOT NULL default '',
  `county` char(3) NOT NULL default '',
  `country` char(2) NOT NULL default '',
  `certification` char(10) NOT NULL default '',
  `status_code` char(1) NOT NULL default '',
  `mode_s_code` char(8) NOT NULL default '',
  `fract_owner` char(1) NOT NULL default '',
  `last_action_date` date NOT NULL default '0000-00-00',
  `cert_issue_date` date NOT NULL default '0000-00-00',
  `air_worth_date` date NOT NULL default '0000-00-00',
  PRIMARY KEY  (`tail_num`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `aircraft_engine_types` (
  `aircraft_engine_type_id` tinyint(3) unsigned NOT NULL default '0',
  `description` char(30) NOT NULL default '',
  PRIMARY KEY  (`aircraft_engine_type_id`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `aircraft_engines` (
  `aircraft_engine_code` char(5) NOT NULL default '',
  `manufacturer` char(10) NOT NULL default '',
  `model` char(13) NOT NULL default '',
  `aircraft_engine_type_id` tinyint(3) unsigned NOT NULL default '0',
  `horsepower` mediumint(8) unsigned NOT NULL default '0',
  `thrust` mediumint(8) unsigned NOT NULL default '0',
  `fuel_consumed` decimal(10,2) NOT NULL default '0.00',
  PRIMARY KEY  (`aircraft_engine_code`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `aircraft_models` (
  `aircraft_model_code` char(7) NOT NULL default '',
  `manufacturer` char(30) NOT NULL default '',
  `model` char(20) NOT NULL default '',
  `aircraft_type_id` tinyint(3) unsigned NOT NULL default '0',
  `aircraft_engine_type_id` tinyint(3) unsigned NOT NULL default '0',
  `aircraft_category_id` tinyint(3) unsigned NOT NULL default '0',
  `amateur` tinyint(3) unsigned NOT NULL default '0',
  `engines` tinyint(4) NOT NULL default '0',
  `seats` smallint(6) NOT NULL default '0',
  `weight` int(11) NOT NULL default '0',
  `speed` smallint(6) NOT NULL default '0',
  PRIMARY KEY  (`aircraft_model_code`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `aircraft_types` (
  `aircraft_type_id` tinyint(3) unsigned NOT NULL default '0',
  `description` char(30) NOT NULL default '',
  PRIMARY KEY  (`aircraft_type_id`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `airport_remarks` (
  `airport_remark_id` int(11) NOT NULL auto_increment,
  `site_number` varchar(11) NOT NULL default '',
  `element_name` varchar(8) NOT NULL default '',
  `remark` text NOT NULL,
  PRIMARY KEY  (`airport_remark_id`),
  KEY `site_number` (`site_number`,`element_name`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `airports` (
  `id` int(11) NOT NULL auto_increment,
  `code` char(4) NOT NULL default '',
  `site_number` char(16) NOT NULL default '',
  `fac_type` char(14) NOT NULL default '',
  `fac_use` char(2) NOT NULL default '',
  `faa_region` char(3) NOT NULL default '',
  `faa_dist` char(4) NOT NULL default '',
  `city` char(30) NOT NULL default '',
  `county` char(30) NOT NULL default '',
  `state` char(2) NOT NULL default '',
  `full_name` char(50) NOT NULL default '',
  `own_type` char(2) NOT NULL default '',
  `longitude` double(16,6) NOT NULL default '0.000000',
  `latitude` double(16,6) NOT NULL default '0.000000',
  `elevation` smallint(6) NOT NULL default '0',
  `aero_cht` char(30) NOT NULL default '',
  `cbd_dist` smallint(6) NOT NULL default '0',
  `cbd_dir` char(3) NOT NULL default '',
  `act_date` char(7) NOT NULL default '',
  `cert` char(10) NOT NULL default '',
  `fed_agree` char(7) NOT NULL default '',
  `cust_intl` char(1) NOT NULL default '',
  `c_ldg_rts` char(1) NOT NULL default '',
  `joint_use` char(1) NOT NULL default '',
  `mil_rts` char(1) NOT NULL default '',
  `cntl_twr` char(1) NOT NULL default '',
  `major` enum('N','Y') NOT NULL default 'N',
  PRIMARY KEY  (`id`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `carriers` (
  `code` char(2) NOT NULL default '',
  `name` char(60) NOT NULL default '',
  `nickname` char(20) NOT NULL default '',
  PRIMARY KEY  (`code`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `exceptions` (
  `carrier` char(2) NOT NULL default '',
  `bad_tail_num` char(6) NOT NULL default '',
  `good_tail_num` char(6) NOT NULL default '',
  `owner_name` char(30) NOT NULL default '',
  `first_seen` date NOT NULL default '0000-00-00',
  `last_seen` date NOT NULL default '0000-00-00',
  PRIMARY KEY  (`carrier`,`bad_tail_num`,`good_tail_num`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `ontime_all` (
  `id` int(10) unsigned NOT NULL , -- auto_increment,
  `carrier` char(2) NOT NULL default '',
  `origin` char(3) NOT NULL default '',
  `destination` char(3) NOT NULL default '',
  `flight_num` char(5) NOT NULL default '',
  `flight_time` smallint(5) unsigned NOT NULL default '0',
  `tail_num` char(8) NOT NULL default '',
  `dep_time` datetime NOT NULL default '0000-00-00 00:00:00',
  `arr_time` datetime NOT NULL default '0000-00-00 00:00:00',
  `dep_delay` smallint(6) NOT NULL default '0',
  `arr_delay` smallint(6) NOT NULL default '0',
  `taxi_out` smallint(6) NOT NULL default '0',
  `taxi_in` smallint(6) NOT NULL default '0',
  `distance` smallint(5) unsigned NOT NULL default '0',
  `cancelled` enum('Y','N') NOT NULL default 'Y',
  `diverted` enum('Y','N') NOT NULL default 'Y' -- ,
) DEFAULT CHARSET=latin1;

  -- PRIMARY KEY  (`id`)

CREATE TABLE `states` (
  `state_code` char(2) NOT NULL default '',
  `name` char(50) NOT NULL default '',
  PRIMARY KEY  (`state_code`)
) DEFAULT CHARSET=latin1;

CREATE TABLE `zipcodes` (
  `zipcode_id` int(11) NOT NULL auto_increment,
  `zipcode` char(5) NOT NULL default '',
  `state_fips` tinyint(4) NOT NULL default '0',
  `state_code` char(2) NOT NULL default '',
  `name` char(50) NOT NULL default '',
  `longitude` double NOT NULL default '0',
  `latitude` double NOT NULL default '0',
  `population` int(11) NOT NULL default '0',
  `allocation` double NOT NULL default '0',
  PRIMARY KEY  (`zipcode_id`),
  UNIQUE KEY `zipcode` (`zipcode`)
) DEFAULT CHARSET=latin1;

-- Original FlightStats indexes
CREATE INDEX idx_code ON `airports`(code);
CREATE INDEX idx_state ON `airports`(state,city);
CREATE INDEX idx_state_2 ON `airports`(state,county);
CREATE INDEX idx_longitude ON `airports`(longitude,latitude,elevation);
-- Index with poor data distribution
CREATE INDEX idx_major ON `airports`(major);

-- Original FlightStats indexes
CREATE INDEX idx_carrier ON `ontime_all`(carrier);
CREATE INDEX idx_origin ON `ontime_all`(origin,destination);
CREATE INDEX idx_destination ON `ontime_all`(destination);
CREATE INDEX idx_tail_num ON `ontime_all`(tail_num);
-- Index on departure time
CREATE INDEX idx_dep_time ON `ontime_all`(dep_time);

CREATE TABLE `ontime_1year` LIKE `ontime_all`;

CREATE TABLE `ontime_3month` LIKE `ontime_all`;

CREATE TABLE `ontime_1week` LIKE `ontime_all`;
CREATE TABLE `ontime_1w_range` LIKE `ontime_all`;
CREATE TABLE `ontime_1w_hash` LIKE `ontime_all`;



